OmiStartCallModel class

Constructors

OmiStartCallModel()

Properties

callInfo ↔ OmiCallModel
latefinal
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ int
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited