OmiStartCallStatus enum

Inheritance
Available extensions

Values

invalidUuid → const OmiStartCallStatus
invalidPhoneNumber → const OmiStartCallStatus
samePhoneNumber → const OmiStartCallStatus
maxRetry → const OmiStartCallStatus
permissionDenied → const OmiStartCallStatus
couldNotFindEndpoint → const OmiStartCallStatus
accountRegisterFailed → const OmiStartCallStatus
startCallFailed → const OmiStartCallStatus
startCallSuccess → const OmiStartCallStatus
haveAnotherCall → const OmiStartCallStatus
accountTurnOffNumberInternal → const OmiStartCallStatus
noNetwork → const OmiStartCallStatus

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue → int

Available on OmiStartCallStatus, provided by the ExtensionOmiStartCallStatus extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<OmiStartCallStatus>
A constant List of the values in this enum, in order of their declaration.